%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% This is file `amiart.cls' (2024/02/14)
%% LaTeX document class for Annales Mathematicae et Informaticae
%%
%% Copyright © 2019-2024 Tibor Tómács
%% e-mail: tomacs.tibor@uni-eszterhazy.hu
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\NeedsTeXFormat{LaTeX2e}[2021/10/10]

\begingroup
\def\@latex@warning@no@line#1{} % For \documentclass{../amiart}
\ProvidesClass{amiart}[2024/02/14 LaTeX document class for Annales Mathematicae et Informaticae]
\endgroup

\LoadClass[twoside]{article}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% ERROR MESSAGE WITH XELATEX AND LUALATEX COMPILERS
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{iftex}
\ifpdftex\else
  \ClassError{amiart}{Please, use pdflatex compiler}{}
\fi

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% GENERAL PACKAGES
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{geometry}
\RequirePackage[T1]{fontenc}
\RequirePackage[english]{babel}
\RequirePackage{
  lmodern,
  graphicx,
  xurl,
  xcolor,
  eso-pic,
  tikz,
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% GEOMETRY
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\geometry{
  paperwidth  = 170mm,
  paperheight = 240mm,
  width       = 126mm,
  height      = 189mm,
  headsep     =   5mm,
  top         =  28mm,
  outer       =  22mm,
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% MATH
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage[intlimits]{mathtools}
\RequirePackage{amssymb,mleftright}
\mleftright
\allowdisplaybreaks

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% CAPTION
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{subcaption}
\captionsetup{
  justification=centerlast,
  font=small,
  labelfont=bf,
  labelsep=period,
  width=95mm,
  tableposition=top,
}
\captionsetup[sub]{margin=10pt}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% TABLE CAPTION ON THE TOP OF THE TABLE
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{float}
\floatstyle{plaintop}
\restylefloat{table}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% NO INFORMATION SAVED (REDEFINED BY FINAL OPTION)
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\amiart@saveinfos{}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% AMI NAME, AMI ABBREVIATION, AMI GROUPS, VOLUME NUMBER, YEAR
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\AMIname{Annales Mathematicae et Informaticae}
\def\AMIabbr{Annal.\,Math.\,et\,Inf.}
\def\AMIvolume{??}
\def\AMIyear{????}
\def\AMIgroup#1#2{\expandafter\def\csname amigroup#1\endcsname{#2}}
\newif\ifamiart@showlogo\amiart@showlogotrue
\def\NoLogo{\amiart@showlogofalse}
\InputIfFileExists{../vol.txt}{}{}
\InputIfFileExists{../../vol.txt}{}{}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% INFORMATION IN THE TITLE PAGE
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\amiart@info{%
  \AMIname\\
  URL: \url{https://ami.uni-eszterhazy.hu}\\
  Manuscript, \today}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% SHOWING DATES
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\amiart@dates{%
  \AddToShipoutPictureBG*{%
    \begin{tikzpicture}[overlay]
      \node[anchor=north west,inner sep=0pt,outer sep=0pt] at 
      ([yshift=18mm,xshift=22mm] current page.south west)
      {\parbox{\textwidth}{% 
          \leavevmode\color{gray}% Without \leavevmode the \color puts the baseline of the \parbox[t] below
          \normalfont\scriptsize\sffamily
          \rule{\textwidth}{2pt}\\
          \amiart@submitted\\
          \amiart@accepted\\
          \amiart@published}};
    \end{tikzpicture}}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% AUTHOR SPACE
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\amiart@authorspace{\frenchspacing\spaceskip=.2em\xspaceskip=.33333em\sfcode`\,3000}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% PAGE STYLES
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\pagestyle{empty} % Without \maketitle the pagestyle is empty (for title pages)

\RequirePackage{fancyhdr}

\fancypagestyle{amiart@titlepagestyle}{
  \fancyhf{}
  \fancyhead[L]{\parbox[t]{\textwidth}{%
      \leavevmode\color{gray}% Without \leavevmode the \color puts the baseline of the \parbox[t] below
      \normalfont\small\sffamily%
      \amiart@info\\
      \rule[0.5em]{\textwidth}{2pt}}}
  \ifamiart@manuscript
      \fancyfoot[C]{\normalfont\normalsize\sffamily\color{gray}\thepage}\fi
  \def\headrulewidth{0pt}}

\fancypagestyle{amiart@pagestyle}{
  \fancyhf{}
  \fancyfoot[C]{\normalfont\normalsize\sffamily\color{gray}\thepage}
  \fancyhead[L]{\normalfont\small\sffamily\color{gray}
                Manuscript for the \AMIname}
  \fancyhead[R]{\normalfont\small\sffamily\color{gray}\today}
  \def\headrulewidth{0.4pt}}

\def\amiart@finalpagestyle{
  \fancypagestyle{amiart@pagestyle}{
  \fancyhf{}
  \fancyfoot[C]{\normalfont\normalsize\sffamily\color{gray}\thepage}
  \fancyhead[RE]{\amiart@authorspace\normalfont\small\itshape\amiart@authorinheadline}
  \fancyhead[RO]{\normalfont\small\itshape\amiart@titleinheadline}
  \fancyhead[L]{\normalfont\small\sffamily\color{gray}\AMIabbr}
  \def\headrulewidth{0.4pt}}}

\def\f@nch@warning#1{} % Turn off fancyhdr warning (amiart@titlepagestyle is too high)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% OPTIONS
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\newif\ifamiart@manuscript\amiart@manuscripttrue
\newif\ifamiart@unproof
\newif\ifamiart@inpress
\newif\ifamiart@final
\newif\ifamiart@volume

\DeclareOption{unproof}{\amiart@manuscriptfalse\amiart@unprooftrue\amiart@inpressfalse\amiart@finalfalse}
\DeclareOption{inpress}{\amiart@manuscriptfalse\amiart@unprooffalse\amiart@inpresstrue\amiart@finalfalse}
\DeclareOption{final}{\amiart@manuscriptfalse\amiart@unprooffalse\amiart@inpressfalse\amiart@finaltrue}
\DeclareOption{checktoc}{\AtEndOfPackage{\amiart@checktoc}}
\DeclareOption{volume}{\amiart@volumetrue}

\ProcessOptions\relax

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% OPTION: CHECKTOC
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\l@section{\@dottedtocline{0}{0pt}{2.3em}}

\def\amiart@checktoc{%
  \ifamiart@manuscript\else
    \AddToHook{cmd/maketitle/before}{%
      \hypersetup{pageanchor=false}
      \thispagestyle{empty}
      \section*{Checking contents line}
      \babel@toc{english}{}\relax
      \contentsline{section}{Checking contents line checking contents line checking contents line checking contents line}{100}{}
      \contentsline{section}{\textsc{\amiart@authorspace\amiart@authorinpdfcontents},
         \amiart@titleinpdfcontents}{100}{}
      \newpage
      \hypersetup{pageanchor}
      \setcounter{page}{1}}
   \fi}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% OPTION: UNPROOF
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\ifamiart@unproof

\amiart@finalpagestyle

\def\amiart@info{%
  \AMIname\\
  Uncorrected proof\\
  DOI: \amiart@doi\\
  URL: \url{https://ami.uni-eszterhazy.hu}}

\RequirePackage[mathlines]{lineno}
\def\linenumberfont{\normalfont\tiny\sffamily\color{gray}}
\setlength\linenumbersep{10mm}
\linenumbers

\AddToShipoutPictureBG{%
  \begin{tikzpicture}[overlay]
    \node[rotate=48,color=black!5] at (current page.center)
    {\resizebox*{180mm}{!}{\normalfont\bfseries\sffamily UNCORRECTED PROOF}};
  \end{tikzpicture}}

\fi

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% OPTION: INPRESS
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\ifamiart@inpress

\amiart@finalpagestyle

\def\amiart@info{%
  \AMIname\\
  Accepted manuscript\\
  DOI: \amiart@doi\\
  URL: \url{https://ami.uni-eszterhazy.hu}}

\fi

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% OPTION: FINAL
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\ifamiart@final

\RequirePackage{newfile}

\amiart@finalpagestyle

\definecolor{amiyellow}{cmyk}{0,0,.3,0}

\def\amiart@logo{%
  \ifamiart@showlogo%
    \hfill
    \raisebox{3pt}
    {\smash{\colorbox{amiyellow}{\includegraphics[height=12mm]{../../cover/graphics/summa}}}}%
  \fi}

\newcounter{FirstPage}
\newcounter{LastPage}

\def\amiart@info{%
  \AMIname\\
  \AMIvolume\ (\AMIyear) pp.~\thepage--\theLastPage\\
  DOI: \amiart@doi\\
  URL: \url{https://ami.uni-eszterhazy.hu}
  \amiart@logo}

\InputIfFileExists{../firstpage.txt}{}{}

\def\amiart@saveinfos{
  \setcounter{FirstPage}{\inteval{\value{page}+\@abspage@last}}
  \setcounter{LastPage}{\inteval{\value{page}+\@abspage@last-1}}
  \newoutputstream{firstpage}
  \openoutputfile{firstpage.txt}{firstpage}
  \addtostream{firstpage}{\protect\setcounter{page}{\theFirstPage}}
  \closeoutputstream{firstpage}
  \newoutputstream{htmlcontents}
  \openoutputfile{htmlcontents.txt}{htmlcontents}
  \addtostream{htmlcontents}{source: \jobname}
  \addtostream{htmlcontents}{\amiart@authorinhtmlcontents}
  \addtostream{htmlcontents}{\amiart@titleinhtmlcontents}
  \addtostream{htmlcontents}{\thepage–\theLastPage}
  \addtostream{htmlcontents}{\space}
  \closeoutputstream{htmlcontents}
  \newoutputstream{pdfcontents}
  \openoutputfile{pdfcontents.txt}{pdfcontents}
  \addtostream{pdfcontents}{\protect\VOLtocline{\jobname}{\amiart@authorinpdfcontents}{\amiart@titleinpdfcontents}{\thepage}}
  \closeoutputstream{pdfcontents}}

\fi

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% BIBLATEX
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{csquotes} % For biblatex package (after lineno)

\IfFileExists{ext-numeric-comp.bbx}
  {\RequirePackage[
      style       = ext-numeric-comp,
      articlein   = false,
      giveninits,
      maxbibnames = 50
    ]{biblatex}}
  {\RequirePackage[maxbibnames=50]{biblatex}}

\def\bibfont{\normalfont\footnotesize}
\def\mkbibnamefamily{\scshape}
\def\mkbibnamegiven{\scshape}
\def\newunitpunct{\addcomma\addspace}
\def\finalnamedelim{\addcomma\addspace}
\def\labelnamepunct{\addcolon\addspace}
\setlength{\biblabelsep}{\labelsep}
\DeclareFieldFormat*{title}{\textit{#1}}
\DeclareFieldFormat*{booktitle}{\textnormal{#1}}
\DeclareFieldFormat*{journaltitle}{\textnormal{#1}}

\setcounter{biburllcpenalty}{100} % for xurl (or load xurl after biblatex) 
\setcounter{biburlucpenalty}{200} % for xurl (or load xurl after biblatex) 
\setcounter{biburlnumpenalty}{100} % for xurl (or load xurl after biblatex) 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% AUTHOR, TITLE
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\author#1{\def\amiart@author{#1}}
\def\amiart@author{Author(s)}

\def\authorinheadline#1{\def\amiart@authorinheadline{#1}}
\def\amiart@authorinheadline{\amiart@author}

\def\authorinhtmlcontents#1{\def\amiart@authorinhtmlcontents{#1}}
\def\amiart@authorinhtmlcontents{\amiart@author}

\def\authorinpdfcontents#1{\def\amiart@authorinpdfcontents{#1}}
\def\amiart@authorinpdfcontents{\amiart@author}

\def\authorinpdfmetadata#1{\def\amiart@authorinpdfmetadata{#1}}
\def\amiart@authorinpdfmetadata{\amiart@author}

\def\title#1{\def\amiart@title{#1}}
\def\amiart@title{Title}

\def\titleinheadline#1{\def\amiart@titleinheadline{#1}}
\def\amiart@titleinheadline{\amiart@title}

\def\titleinhtmlcontents#1{\def\amiart@titleinhtmlcontents{#1}}
\def\amiart@titleinhtmlcontents{\amiart@title}

\def\titleinpdfcontents#1{\def\amiart@titleinpdfcontents{#1}}
\def\amiart@titleinpdfcontents{\amiart@title}

\def\titleinpdfmetadata#1{\def\amiart@titleinpdfmetadata{#1}}
\def\amiart@titleinpdfmetadata{\amiart@title}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% DATES
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\amiart@submitted{\textcolor{red}{Submitted: $\langle$date\/$\rangle$}}
\def\amiart@accepted{\textcolor{red}{Accepted: $\langle$date\/$\rangle$}}
\ifamiart@unproof
    \def\amiart@published{Published online: $\langle$none\/$\rangle$}
  \else
    \def\amiart@published{\textcolor{red}{Published online: $\langle$none\/$\rangle$}}
  \fi
\def\amiart@date{\amiart@submitted\\\amiart@accepted\\\amiart@published}
\def\amiart@@date#1-#2-#3#4{\ifcase#2\or January\or February\or March\or April\or May\or June\or July\or August\or September\or October\or November\or December\fi~\ifx0#3\else#3\fi#4,~#1}
\def\submitted#1{\def\amiart@submitted{Submitted:~\amiart@@date#1}}
\def\accepted#1{\def\amiart@accepted{Accepted:~\amiart@@date#1}}
\def\published#1{\def\amiart@published{Published~online:~\amiart@@date#1}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% DOI, INSTITUTE, INST, EMAIL, THANKS, THANKSMARK, DEDICATED
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\doi#1{\def\amiart@doi{\href{https://doi.org/#1}{\nolinkurl{#1}}}}

\def\institute#1{\def\amiart@institute{\def\amiart@instsep{\par\vspace{1.5mm}}#1}}
\institute{Institute(s)}

\RequirePackage{accsupp}
\DeclareRobustCommand{\amiart@uncopyable}[1]{\BeginAccSupp{ActualText=}#1\EndAccSupp{}}

\def\amiart@instsep{}
\newcounter{amiart@inst}
\def\inst#1{%
  \ifhmode\unskip\fi% ignore space before \inst
  \setcounter{amiart@inst}{#1}%
  \ifnum\value{amiart@inst}>1\amiart@instsep\fi%
  \textsuperscript{\amiart@uncopyable{\color{gray}\normalfont\sffamily\alph{amiart@inst}}}%
  \ignorespaces}% ignore space after \inst

\def\thanks#1{%
  \unskip%
  \def\thefootnote{\amiart@uncopyable{\normalfont\fnsymbol{footnote}}}%
  \footnote{#1}}

\newcounter{thankscount}
\def\thanksmark#1{%
  \unskip%
  \setcounter{thankscount}{\value{footnote}}%
  \setcounter{footnote}{#1}%
  \setcounter{Hfootnote}{#1}%
  \addtocounter{footnote}{-1}%
  \addtocounter{Hfootnote}{-1}%
  \def\thefootnote{\amiart@uncopyable{\normalfont\fnsymbol{footnote}}}%
  \footnotemark%
  \setcounter{footnote}{\value{thankscount}}%
  \setcounter{Hfootnote}{\value{thankscount}}}

\def\email#1{\href{mailto:#1}{{\def\UrlFont{\normalfont}\nolinkurl{#1}}}}

\def\dedicated#1{\def\amiart@dedicated{#1}}
\def\amiart@dedicated{}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% KEYWORDS, AMS SUBJECT CLASSIFICATIONS
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\keywords{\par\vspace{1.5mm}\noindent\textit{Keywords:}~}
\def\AMSSubjectClassification{\par\vspace{1.5mm}\noindent\textit{AMS Subject Classification:}~}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% ABSTRACT
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\renewenvironment{abstract}{%
  \begin{quotation}
  \noindent\small\normalfont\textbf{Abstract.}\enskip\ignorespaces}
  {\end{quotation}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% SECTION TITLE FORMAT
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{titlesec}
\titleformat{\section}{\normalfont\Large\bfseries}{\thesection.}{.44em}{}
\titleformat{\subsection}{\normalfont\large\bfseries}{\thesubsection.}{.44em}{}
\titleformat{\subsubsection}{\normalfont\normalsize\bfseries}{\thesubsubsection.}{.44em}{}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% EQUATION NUMBERS
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\numberwithin{equation}{section}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% THEOREM-LIKE ENVIRONMENTS
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{amsthm}
\newtheorem{theorem}{Theorem}[section]
\newtheorem{lemma}[theorem]{Lemma}
\newtheorem{corollary}[theorem]{Corollary}
\theoremstyle{definition}
\newtheorem{definition}[theorem]{Definition}
\newtheorem{example}[theorem]{Example}
\newtheorem{remark}[theorem]{Remark}
\theoremstyle{plain} % Back to the default style

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% BOLDFACE PROOF
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\renewenvironment{proof}[1][\proofname]{\par
  \pushQED{\qed}%
  \normalfont \topsep6\p@\@plus6\p@\relax
  \trivlist
  \item[\hskip\labelsep
        \bfseries\itshape\begin{NoHyper}%
    #1\end{NoHyper}\@addpunct{.}]\ignorespaces
}{%
  \popQED\endtrivlist\@endpefalse
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% WARNING: DO NOT USE THEBIBLIOGRAPHY ENVIRONMENT!
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RenewDocumentEnvironment{thebibliography}{+b}{%
  \@gobble{#1}%
  \section*{References}
  {\color{red}%
   Please, use \texttt{\textbackslash printbibliography}
   instead of \texttt{thebibliography} environment!}}{}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% BOLD MATH IN TITLE (BUT NOT IN \thanks)
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\AddToHook{bfseries}{\boldmath}
\AddToHook{cmd/thanks/before}{\unboldmath}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% HYPERREF
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage[
  colorlinks   = true,
  bookmarks    = false,
  pdfusetitle  = false,
  pdfstartview = FitH,
  urlcolor     = blue!60!black,
  citecolor    = teal,
  linkcolor    = blue,
]{hyperref}

\ifamiart@unproof
  \AddToHook{cmd/maketitle/before}{%
    \hypersetup{
      pdftitle   = {\amiart@titleinpdfmetadata},
      pdfauthor  = {\amiart@authorinpdfmetadata},
      pdfsubject = {\AMIname, Uncorrected proof},
    }}
\fi

\ifamiart@inpress
  \AddToHook{cmd/maketitle/before}{%
    \hypersetup{
      pdftitle   = {\amiart@titleinpdfmetadata},
      pdfauthor  = {\amiart@authorinpdfmetadata},
      pdfsubject = {\AMIname, Accepted manuscript},
    }}
\fi

\ifamiart@final
  \AddToHook{cmd/maketitle/before}{%
    \hypersetup{
      pdftitle   = {\amiart@titleinpdfmetadata},
      pdfauthor  = {\amiart@authorinpdfmetadata},
      pdfsubject = {\AMIname\ \AMIvolume\ (\AMIyear)},
    }}
\fi

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% MAKE TITLE
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\maketitle{
  \amiart@saveinfos
  \ifamiart@manuscript\else\amiart@dates\fi
  \thispagestyle{amiart@titlepagestyle}
  \pagestyle{amiart@pagestyle}
  \vspace*{25mm}
  \begingroup
    \centering
    \normalfont\normalsize
    {\LARGE\bfseries\amiart@title\\}\vskip8mm
    {\large\bfseries\amiart@author\\}\vskip5mm
    {\small\rmfamily\amiart@institute\\}\vskip8mm
    \ifx\amiart@dedicated\empty\else{\itshape\amiart@dedicated\\}\vskip8mm\fi
    \par
  \endgroup
  \setcounter{footnote}{0}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% OPTION: VOLUME
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\ifamiart@volume

\RequirePackage{etoolbox,xstring,pdfpages,newpax}
\newpaxsetup{usefileattributes=true}

\AddToHook{begindocument/end}{
  \hypersetup{
    pdftitle={\AMIname\ \AMIvolume\ (\AMIyear)},
    pageanchor=false}}

\def\VOLtocline#1#2#3#4{%
  \StrBefore{#1}{_}[\ami@group]%
  \ifcsvoid{amigroup\ami@group}{}{%
    \medskip\noindent
    \begingroup
    \normalfont\bfseries\@nameuse{amigroup\ami@group}
    \endgroup
    \par\medskip%
  }%
  \csgundef{amigroup\ami@group}%
  \contentsline{section}{\textsc{\amiart@authorspace#2}, #3}{\hyperpage{#4}}{}}

\def\tableofcontents{
  \clearpage
  \section*{Contents}
  \babel@toc{english}{}\relax
  \input{pdfcontents.txt}
  \ifodd\value{page}\newpage\mbox{}\fi
  \setcounter{page}{0}
  \hypersetup{pageanchor}}

\fi

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% END
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\endinput